@@ -1,6 +1,6 @@
 """Implements a HD44780 character LCD connected via PCF8574 on I2C. 
    This was tested with: https://www.wemos.cc/product/d1-mini.html""" 
-import LcdApi 
+from lcd_api import LcdApi 
 from machine import I2C 
 from time import sleep_ms 
 # The PCF8574 has a jumper selectable address: 0x20 - 0x27 
